@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.20';
+our $VERSION = '1.21';
 
 use Carp;
 use Fcntl qw(:flock);
@@ -35,6 +35,7 @@ sub read {
     }
 
     $self->recsep($file);
+    $self->{files}{$file}{recsep} = $self->{recsep};
     $self->{is_read} = 1;
 
     my $fh;
@@ -44,13 +45,13 @@ sub read {
         return $fh;
     }
     else {
-        $fh = $self->_open($file); 
+        $fh = $self->_open($file);
         my @contents = <$fh>;
         close $fh or confess "read() can't close file $file!: $!";
 
         if (! $testing){
             for (@contents){
-                s/[\n\x{0B}\f\r\x{85}]{1,2}//;
+                $_ = $self->_strip_ends($_);
             }
         }
         return @contents;
@@ -58,12 +59,19 @@ sub read {
 }
 sub write {
     my $self = shift;
-    $self->_config(@_);
+    my %p = @_;
+    $self->_config(%p);
 
     if (! $self->{file}){
         confess "write() requires a file to be passed in!";
     }
 
+    if (keys %{ $self->{files} } > 1 && ! $p{file}){
+        confess "if calling write() with more than one read() open, you must " .
+                "send in a file name with the 'file' parameter so we know " .
+                "which file to write. You currently have the following files " .
+                "open: " . join(' ', keys %{ $self->{files} }) . "\n";
+    }
     if (! $self->{contents}){
         confess "write() requires 'contents' param sent in";
     }
@@ -72,6 +80,8 @@ sub write {
         $self->recsep($self->{file});
     }
 
+    my $file = $self->{file}; # needed for cleanup of open file list
+
     $self->{file} = $self->{copy} if $self->{copy};
 
     my $wfh = $self->_open($self->{file}, 'w');
@@ -95,21 +105,22 @@ sub write {
         seek $contents, 0, 0;
 
         while (<$contents>){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}//g;
+            $_ = $self->_strip_ends($_);
             print $wfh $_ . $recsep;
         }
         close $contents;
     }
     else {
         for (@$contents){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}//g;
+            $_ = $self->_strip_ends($_);
             print $wfh $_ . $recsep;
         }
     }
 
     close $wfh;
     $self->{is_read} = 0;
-    
+    delete $self->{files}{$file}; # cleanup open list
+
     return 1;
 }
 sub splice {
@@ -128,7 +139,8 @@ sub splice {
     my ($line, $find) = ($self->{line}, $self->{find});
 
     if (! defined $line && ! defined $find){
-        confess "splice() requires either the 'line' or 'find' parameter sent in.";
+        confess
+          "splice() requires either the 'line' or 'find' parameter sent in.";
     }
 
     if (defined $line && defined $find){
@@ -204,12 +216,12 @@ sub dir {
         close $fh;
 
         $self->write(
-                    file => $file, 
-                    contents => $wfh,
-                    recsep => defined $recsep
-                        ? $recsep
-                        : $self->platform_recsep,
-                );
+            file => $file,
+            contents => $wfh,
+            recsep => defined $recsep
+                ? $recsep
+                : $self->platform_recsep,
+        );
     }
 
     return @files;
@@ -217,64 +229,52 @@ sub dir {
 sub recsep {
     my $self = shift;
     my $file = shift;
-    my $hex = shift if @_;
+    my $want = shift if @_;
 
-    my $fh; 
+    my $fh;
     eval {
         $fh = $self->_open($file);
     };
 
-    my $recsep;
-
-    if ($@ || ! <$fh>){
+    if ($@ || ! $fh){
 
         # we've got an empty file...
         # we'll set recsep to the local platform's
 
-        $recsep = $self->platform_recsep;
-        $self->{recsep} = $recsep;
+        $self->{recsep} = $self->platform_recsep;
 
-        if ($hex){
-            $recsep = unpack "H*", $recsep;
-            $recsep =~ s/0/\\0/g;
-            return $recsep;
-        }
-        else {
-            return $self->{recsep};
-        }
+        return $want
+            ? $self->_convert_recsep($self->{recsep}, $want)
+            : $self->{recsep};
     }
 
     seek $fh, 0, 0;
 
-    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2})/){
+    my $recsep_regex = $self->_recsep_regex;
+
+    if (<$fh> =~ /$recsep_regex/){
         $self->{recsep} = $1;
     }
 
     close $fh or confess "recsep() can't close file $file!: $!";
-   
-    if ($hex){ 
-        $recsep = unpack "H*", $self->{recsep};
-        $recsep =~ s/0/\\0/g;
-        return $recsep;
-    }
-    else {
-        return $self->{recsep};
-    }
+
+    return $want
+        ? $self->_convert_recsep($self->{recsep}, $want)
+        : $self->{recsep};
 }
 sub platform_recsep {
 
     my $self = shift;
-    my $hex = shift if @_;
+    my $want = shift if @_;
 
     my $file = $self->_temp_filename;
 
-    push @{ $self->{temp_files} }, $file;
-
     # for platform_recsep(), we need the file open in ASCII mode,
     # so we can't use _open() or File::Temp
 
     open my $wfh, '>', $file
-      or die "platform_recsep() can't open temp file $file for writing!: $!";
+      or confess
+        "platform_recsep() can't open temp file $file for writing!: $!";
 
     print $wfh "abc\n";
 
@@ -283,21 +283,18 @@ sub platform_recsep {
 
     my $fh = $self->_open($file);
 
-    if (<$fh> =~ /([\n\x{0B}\f\r\x{85}]{1,2})/){
+    my $recsep_regex = $self->_recsep_regex;
+
+    if (<$fh> =~ /$recsep_regex/){
         $self->{platform_recsep} = $1;
     }
 
     close $fh
       or confess "platform_recsep() can't close temp file $file after run: $!";
 
-    if ($hex){
-        my $recsep = unpack "H*", $self->{platform_recsep};
-        $recsep =~ s/0/\\0/g;
-        return $recsep;
-    }
-    else {
-        return $self->{platform_recsep};
-    }
+    return $want
+        ? $self->_convert_recsep($self->{platform_recsep}, $want)
+        : $self->{platform_recsep};
 }
 sub tempfile {
     my $wfh = File::Temp->new(UNLINK => 1);
@@ -339,17 +336,13 @@ sub _handle {
 
         my $temp_filename = $temp_wfh->filename;
 
-        push @{ $self->{temp_files} }, $temp_filename;
-
-        my $platform_recsep = $self->platform_recsep;
-
         while (<$fh>){
-            s/[\n\x{0B}\f\r\x{85}]{1,2}/$platform_recsep/g;
+            $_ = $self->_platform_replace($_);
             print $temp_wfh $_;
         }
         
-        close $fh or die "can't close file $file: $!";
-        close $temp_wfh or die "can't close file $temp_filename: $!";
+        close $fh or confess "can't close file $file: $!";
+        close $temp_wfh or confess "can't close file $temp_filename: $!";
 
         my $ret_fh = $self->_open($temp_filename);
         
@@ -382,30 +375,55 @@ sub _open {
 
     return $fh;
 }
+sub _convert_recsep {
+    # converts recsep to either hex or OS name
+
+    my ($self, $sep, $want) = @_;
+
+    if ($want eq 'hex'){
+        $sep = unpack "H*", $sep;
+        $sep =~ s/0/\\0/g;
+        return $sep;
+    }
+    elsif ($want eq 'type'){
+        my $hex_sep = $self->_convert_recsep($sep, 'hex');
+        return 'nix' if $hex_sep =~ /^\\0a$/;
+        return 'win' if $hex_sep =~ /^\\0d\\0a$/;
+        return 'mac' if $hex_sep =~ /^\\0d$/;
+        return 'unknown';
+    }
+}
+sub _recsep_regex {
+    # returns a regex object representing all recseps
+    my $re = qr/([\n\x{0B}\f\r\x{85}]{1,2})/;
+    return $re;
+}
+sub _platform_replace {
+    # replace recseps in a string with the platform recsep
+
+    my ($self, $str) = @_;
+    my $re = $self->_recsep_regex;
+    $str =~ s/$re/$self->platform_recsep/ge;
+    return $str;
+}
+sub _strip_ends {
+    # strip all line endings from string
+
+    my ($self, $str) = @_;
+    my $re = $self->_recsep_regex;
+    $str =~ s/$re//g;
+    return $str;
+}
 sub _temp_filename {
-    my $self = shift;
+    shift;
 
     my $temp_fh = File::Temp->new(UNLINK => 1);
-
-    my $file = $temp_fh->filename;
+    my $filename = $temp_fh->filename;
 
     close $temp_fh
-     or confess "_temp_filename() can't close the $file temp file: $!";
+     or confess "_temp_filename() can't close the $filename temp file: $!";
 
-    return $file;
-}
-sub DESTROY {
-    my $self = shift;
-
-    for (@{ $self->{temp_files} }){
-        if (-f && $^O ne 'MSWin32'){
-            eval { unlink $_ or die $!; };
-            if ($@){
-                confess "File::Temp didn't unlink $_ temp file, and we " .
-                      "can't unlink it in our DESTROY() either!: $@";
-            }
-        }
-    }
+    return $filename;
 }
 sub _vim_placeholder { return 1; }; # for folding
 
@@ -468,7 +486,12 @@ File::Edit::Portable - Read and write files while keeping the original line-endi
     # insert new data into a file after a found search term
 
     $rw->splice(file => 'file.txt', find => 'term', insert => \@contents);
-    
+
+    # get a file's record separator
+
+    $rw->recsep('file.txt'); # string form
+    $rw->recsep('file.txt', 'hex'); # hex form
+    $rw->recsep('file.txt', 'type');  # line ending type (nix, win, mac, etc)
 
 =head1 DESCRIPTION
 
@@ -517,11 +540,13 @@ Writes the data back to the original file, or alternately a new file. Returns 1
 on success. If you inadvertantly append newlines to the new elements of the
 contents array, we'll strip them off before appending the real newlines.
 
-Parameters: 
+Parameters:
 
 C<file =E<gt> 'file.txt'>
 
-Not needed if you've used C<read()> to open the file.
+Not needed if you've used C<read()> to open the file. However, if you have
+multiple C<read()>s open, C<write()> will die without the 'file' param, as it
+won't know which file you're wanting to write.
 
 C<copy =E<gt> 'file2.txt'>
 
@@ -553,7 +578,7 @@ Mandatory.
 
 C<insert =E<gt> \@contents>
 
- Mandatory - an array reference containing the contents to merge into the file.
+Mandatory - an array reference containing the contents to merge into the file.
 
 C<copy =E<gt> 'file2.txt'>
 
@@ -620,19 +645,24 @@ files found, but won't take any editing action on them.
 
 Default is disabled.
 
-=head2 C<recsep('file.txt', 'hex')>
+=head2 C<recsep('file.txt', $want)>
 
 Returns the record separator found within the file. If the file is empty, we'll
 return the local platform's default record separator.
 
-If the optional string parameter 'hex' is sent in, we'll return the record
-separator in hex format. Otherwise, by default, it's returned in string form.
+The optional C<$want> parameter can contain either 'hex' or 'type'. If 'hex' is
+sent in, the record separator will be returned in hex form (eg: "\0d\0a" for
+Windows). If 'type' is sent in, we'll return a short-form of the line-ending
+type (eg: win, nix, mac, etc).
 
-=head2 C<platform_recsep('hex')>
+=head2 C<platform_recsep($want)>
 
-Returns the the current platform's (OS) record separator. If the optional
-string value "hex" is sent in, we'll return the recsep in hex format.
-Otherwise, we'll return it in as-is string format.
+Returns the the current platform's (OS) record separator in string form.
+
+The optional C<$want> parameter can contain either 'hex' or 'type'. If 'hex' is
+sent in, the record separator will be returned in hex form (eg: "\0d\0a" for
+Windows). If 'type' is sent in, we'll return a short-from of the line-ending
+type (eg: win, nix, mac, etc).
 
 =head2 C<tempfile>
 
